@@ -120,6 +120,7 @@ class MotionEyeClient:
     async def _async_request(
         self,
         path: str,
+        params: dict[str, Any] | None = None,
         data: dict[str, Any] | None = None,
         method: str = "GET",
         admin: bool = True,
@@ -129,6 +130,7 @@ class MotionEyeClient:
         serialized_json = json.dumps(data) if data is not None else None
         url = self._build_url(
             path,
+            params=params,
             data=serialized_json,
             method=method,
             admin=admin,
@@ -155,7 +157,7 @@ class MotionEyeClient:
                     raise MotionEyeClientInvalidAuthError(response)
                 elif not response.ok:
                     _LOGGER.warning(
-                        f"Unexpected return code {response.status} for request: {url}"
+                        f"Unexpected HTTP response status code {response.status} for request: {url}"
                     )
                     raise MotionEyeClientRequestError(response)
                 try:
@@ -163,12 +165,15 @@ class MotionEyeClient:
                         content_type=None
                     )
                     return return_value
-                except json.decoder.JSONDecodeError:
-                    _LOGGER.debug(f"Could not JSON decode: {await response.text()}")
-                    raise MotionEyeClientRequestError(response)
+                except (json.decoder.JSONDecodeError, UnicodeDecodeError) as exc:
+                    _LOGGER.error(f"Could not JSON decode: {await response.read()}")
+                    raise MotionEyeClientRequestError(response) from exc
         except aiohttp.client_exceptions.ClientConnectorError as exc:
             _LOGGER.warning(f"Connection failed to motionEye: {exc}")
-            raise MotionEyeClientConnectionError(exc)
+            raise MotionEyeClientConnectionError(exc) from exc
+        except aiohttp.client_exceptions.ClientError as exc:
+            _LOGGER.warning(f"Request failed to motionEye: {exc}")
+            raise MotionEyeClientRequestError(exc) from exc
 
     async def async_client_login(self) -> dict[str, Any] | None:
         """Login to the motionEye server."""
@@ -284,10 +289,18 @@ class MotionEyeClient:
             )
         )
 
-    async def async_get_movies(self, camera_id: int) -> dict[str, Any] | None:
+    async def async_get_movies(
+        self, camera_id: int, prefix: str | None = None
+    ) -> dict[str, Any] | None:
         """Get a motionEye camera config."""
-        return await self._async_request(f"/movie/{camera_id}/list")
+        return await self._async_request(
+            f"/movie/{camera_id}/list", params={"prefix": prefix} if prefix else None
+        )
 
-    async def async_get_images(self, camera_id: int) -> dict[str, Any] | None:
+    async def async_get_images(
+        self, camera_id: int, prefix: str | None = None
+    ) -> dict[str, Any] | None:
         """Get a motionEye camera config."""
-        return await self._async_request(f"/picture/{camera_id}/list")
+        return await self._async_request(
+            f"/picture/{camera_id}/list", params={"prefix": prefix} if prefix else None
+        )
